from setuptools import setup

setup(name='distributions_ahmad',
      version='0.1',
      description='Gaussian distributions , Binomial distributions',
      packages=['distributions_ahmad'],
      zip_safe=False)
